# -*- coding: utf-8 -*-

"""Generate knowledge graphs with interesting geometries, like lattices."""

from .api import (  # noqa:F401
    ChainFactory,
    CircleFactory,
    HexagonalGrid2DFactory,
    LineFactory,
    SquareGrid2DFactory,
    chain_factory,
    circle_factory,
    hex_grid_factory,
    line_factory,
    square_grid_factory,
)
